==> estateplat-common-1.2.1-20170727.080233-71-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJsydsyqLhxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/5/3
 * @description 不动产建设用地使用权量化信息
 */
@Table(name = "bdc_jsydsyq_lhxx")
public class BdcJsydsyqLhxx {
    @Id
    //量化ID
    private String lhid;

    //项目ID
    private String proid;

    //工作流id
    private String wiid;

    //宗地不动产单元号
    private String zdbdcdyh;

    //地籍号
    private String djh;

    //项目名称
    private String xmmc;

    //开发企业名称
    private String kfqymc;

    //土地坐落
    private String tdzl;

    //土地面积
    private Double tdmj;

    //幢号
    private String zrzh;

    //楼幢不动产单元号
    private String lzbdcdyh;

    //工程进度
    private String gcjd;

    //规划建筑面积
    private Double ghjzmj;

    //本幢规划面积占比例（万分比）
    private Double bzghmjzbl;

    //实测建筑面积
    private Double scjzmj;

    //备注
    private String bz;

    public String getLhid() {
        return lhid;
    }

    public void setLhid(String lhid) {
        this.lhid = lhid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getZdbdcdyh() {
        return zdbdcdyh;
    }

    public void setZdbdcdyh(String zdbdcdyh) {
        this.zdbdcdyh = zdbdcdyh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getKfqymc() {
        return kfqymc;
    }

    public void setKfqymc(String kfqymc) {
        this.kfqymc = kfqymc;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLzbdcdyh() {
        return lzbdcdyh;
    }

    public void setLzbdcdyh(String lzbdcdyh) {
        this.lzbdcdyh = lzbdcdyh;
    }

    public String getGcjd() {
        return gcjd;
    }

    public void setGcjd(String gcjd) {
        this.gcjd = gcjd;
    }

    public Double getGhjzmj() {
        return ghjzmj;
    }

    public void setGhjzmj(Double ghjzmj) {
        this.ghjzmj = ghjzmj;
    }

    public Double getBzghmjzbl() {
        return bzghmjzbl;
    }

    public void setBzghmjzbl(Double bzghmjzbl) {
        this.bzghmjzbl = bzghmjzbl;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> estateplat-common-1.2.4-20190528.073213-168-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJsydsyqLhxx.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;

/**
 * @author <a href="mailto:lijian@gtmap.cn">lijian</a>
 * @version 1.0, 2017/5/3
 * @description 不动产建设用地使用权量化信息
 */
@Table(name = "bdc_jsydsyq_lhxx")
public class BdcJsydsyqLhxx {
    @Id
    //量化ID
    private String lhid;

    //项目ID
    private String proid;

    //工作流id
    private String wiid;

    //宗地不动产单元号
    private String zdbdcdyh;

    //地籍号
    private String djh;

    //项目名称
    private String xmmc;

    //开发企业名称
    private String kfqymc;

    //土地坐落
    private String tdzl;

    //土地面积
    private Double tdmj;

    //幢号
    private String zrzh;

    //楼幢不动产单元号
    private String lzbdcdyh;

    //工程进度
    private String gcjd;

    //规划建筑面积
    private Double ghjzmj;

    //本幢规划面积占比例（万分比）
    private Double bzghmjzbl;

    //实测建筑面积
    private Double scjzmj;

    //备注
    private String bz;
    //量化状态
    private String lhzt;

    public String getLhid() {
        return lhid;
    }

    public void setLhid(String lhid) {
        this.lhid = lhid;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getWiid() {
        return wiid;
    }

    public void setWiid(String wiid) {
        this.wiid = wiid;
    }

    public String getZdbdcdyh() {
        return zdbdcdyh;
    }

    public void setZdbdcdyh(String zdbdcdyh) {
        this.zdbdcdyh = zdbdcdyh;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getKfqymc() {
        return kfqymc;
    }

    public void setKfqymc(String kfqymc) {
        this.kfqymc = kfqymc;
    }

    public String getTdzl() {
        return tdzl;
    }

    public void setTdzl(String tdzl) {
        this.tdzl = tdzl;
    }

    public Double getTdmj() {
        return tdmj;
    }

    public void setTdmj(Double tdmj) {
        this.tdmj = tdmj;
    }

    public String getZrzh() {
        return zrzh;
    }

    public void setZrzh(String zrzh) {
        this.zrzh = zrzh;
    }

    public String getLzbdcdyh() {
        return lzbdcdyh;
    }

    public void setLzbdcdyh(String lzbdcdyh) {
        this.lzbdcdyh = lzbdcdyh;
    }

    public String getGcjd() {
        return gcjd;
    }

    public void setGcjd(String gcjd) {
        this.gcjd = gcjd;
    }

    public Double getGhjzmj() {
        return ghjzmj;
    }

    public void setGhjzmj(Double ghjzmj) {
        this.ghjzmj = ghjzmj;
    }

    public Double getBzghmjzbl() {
        return bzghmjzbl;
    }

    public void setBzghmjzbl(Double bzghmjzbl) {
        this.bzghmjzbl = bzghmjzbl;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getLhzt() {
        return lhzt;
    }

    public void setLhzt(String lhzt) {
        this.lhzt = lhzt;
    }
}
